@@ -1,13 +1,12 @@
 //= require parameter_override
 var compute_resource_id = null;
-$(document).ready(function() {
+
+$(document).on('ContentLoad', function() {
   var searchParams = new URLSearchParams(window.location.search);
   if(searchParams.has('hostgroup_id')) {
     var param = searchParams.get('hostgroup_id');
     $('#host_hostgroup_id').val(param).trigger('change');
   }
-});
-$(document).on('ContentLoad', function() {
   onHostEditLoad();
   const overrideButtons = document.querySelectorAll('[name=is_overridden_btn]');
   overrideButtons.forEach(button =>
@@ -38,17 +37,19 @@ $(document).on('ContentLoad', function() {
   update_default_compute_resource($('.hostgroup-select').val());
 });
 $(document)
-  .on('change', '.hostgroup-select', function(evt) {
+  .on('select2:select select2:unselecting', '.hostgroup-select', function(evt) {
     hostgroup_changed(evt.target);
-  }).on('change', '.host-form-compute-resource-handle', function(evt) {
+  }).on('select2:select select2:unselecting', '.host-form-compute-resource-handle', function(evt) {
     computeResourceSelected(evt.target);
-  }).on('change', '.host-taxonomy-select', function(evt) {
+  }).on('select2:select select2:unselecting', '.host-taxonomy-select', function(evt) {
     update_form(evt.target);
-  }).on('change', '.host-architecture-select', function(evt) {
+  }).on('select2:select select2:unselecting', '#host_architecture_id', function(evt) {
     architecture_selected(evt.target);
-  }).on('change', '.host-architecture-os-select', function(evt) {
+  }).on('select2:select select2:unselecting', '#hostgroup_architecture_id', function(evt) {
+    architecture_selected(evt.target);
+  }).on('select2:select select2:unselecting', '.host-architecture-os-select', function(evt) {
     os_selected(evt.target);
-  }).on('change', '.host-os-media-select', function(evt) {
+  }).on('select2:select select2:unselecting', '.host-os-media-select', function(evt) {
     medium_selected(evt.target);
   });
 
@@ -172,11 +173,11 @@ function update_capabilities(capabilities) {
   var build = capabilities.indexOf('build') > -1;
   if (build) {
     $('#manage_network_build').show();
-    $('#host_provision_method_build').click();
+    $('#host_provision_method_build').trigger('click');
     build_provision_method_selected();
   } else if (capabilities.length > 0) {
     $('#manage_network_build').hide();
-    $('#host_provision_method_' + capabilities[0]).click();
+    $('#host_provision_method_' + capabilities[0]).trigger('click');
     if (capabilities[0].toLowerCase() === 'image') {
       image_provision_method_selected();
     }
@@ -377,7 +378,7 @@ function update_form(element, options) {
       if (host_compute_resource_id.exists()) {
         // to handle case if def process_taxonomy changed compute_resource_id to nil
         if (!host_compute_resource_id.val()) {
-          host_compute_resource_id.change();
+          host_compute_resource_id.trigger('change');
         } else {
           // in case the compute resource was selected, we still want to check for
           // free ip if applicable
@@ -428,6 +429,7 @@ function architecture_selected(element) {
     },
     success: function(request) {
       $('#os_select').html(request);
+      os_selected($('.host-architecture-os-select'));
     },
   });
 }
@@ -629,7 +631,7 @@ $(document).on(
   image_provision_method_selected
 );
 
-$(document).on('change', '.interface_domain', function() {
+$(document).on('select2:select select2:unselecting', '.interface_domain', function() {
     interface_domain_selected(this);
     clearIpField(this, '.interface_ip');
     clearIpField(this, '.interface_ip6');
