@@ -70,6 +70,8 @@ module Foreman
         "enable-epel" => "true",
         "package_upgrade" => "true",
         "ansible_tower_provisioning" => "true",
+        "ansible_tower_api_url" => "https://host.example.com/api/controller/v2",
+        "ansible_job_template_id" => "20",
         "schedule_reboot" => "true",
         "fips_enabled" => "true",
         "force-puppet" => "true",
@@ -82,7 +84,6 @@ module Foreman
         "syspurpose_role" => "Red Hat Enterprise Linux Server",
         "syspurpose_usage" => "Development/Test",
         "syspurpose_sla" => "Self-Support",
-        "syspurpose_addons" => "first addon, second addon, third addon",
         "ansible_user" => "win_ansible_user",
         "create_ansible_user" => "true",
         "ansible_ssh_pass" => "win_ansible_user_ssh_pass",
@@ -185,6 +186,7 @@ module Foreman
         name: 'snapshot-ipv4-dhcp-ubuntu20',
         subnet: FactoryBot.build(:subnet_ipv4_dhcp_for_snapshots),
         interfaces: [ipv4_interface])
+      host.define_singleton_method(:managed_interfaces) { interfaces }
       define_host_params(host)
     end
 
