@@ -25,6 +25,7 @@ javascript_driver = ENV.fetch("JS_TEST_DRIVER") { ENV['DEBUG_JS_TEST'] ? :seleni
 
 def chrome_options
   options = Selenium::WebDriver::Chrome::Options.new
+  options.add_option("goog:loggingPrefs", {browser: 'ALL'}) if ENV['SHOW_JS_LOG']
   options.args << '--window-size=1024,768'
   options.args += ENV.fetch('ADDITIONAL_CHROME_OPTIONS', '').split(';')
   options
@@ -111,7 +112,7 @@ class ActionDispatch::IntegrationTest
 
   def assert_new_button(index_path, new_link_text, new_path)
     visit index_path
-    click_link(new_link_text, :class => /^((?!pf-c-nav__link).)*$/)
+    click_link(new_link_text, :class => /^((?!pf-v5-c-nav__link).)*$/)
     assert_current_path new_path
   end
 
@@ -149,18 +150,31 @@ class ActionDispatch::IntegrationTest
     Organization.all_import_missing_ids
   end
 
+  def select2_selector(name)
+    "#select2-#{name}-container"
+  end
+
+  def select2_result_selector(name)
+    "#select2-#{name}-container .select2-results"
+  end
+
+  def select2_chosen_selector(name)
+    find(select2_selector(name), visible: false, wait: 10).ancestor('.select2-container')
+  end
+
   def select2(value, attrs)
-    find("#s2id_#{attrs[:from]}").click
-    wait_for { find('.select2-input').visible? rescue false }
-    wait_for { find(".select2-input").set(value) }
+    find(select2_selector(attrs[:from]), visible: false).ancestor('.select2-container').click
+    wait_for { find('.select2-search__field').visible? rescue false }
+    # set(value) errors on not interactable error even though the element is visible and not disabled
+    page.execute_script("arguments[0].value = arguments[1];", find('.select2-search__field').native, value)
     wait_for { find('.select2-results').visible? rescue false }
-    within ".select2-results" do
-      wait_for { find(".select2-results span", text: value).visible? rescue false }
-      find("span", text: value).click
-    end
-    wait_for do
-      page.find("#s2id_#{attrs[:from]} .select2-chosen").has_text? value
+    within ".select2-results__options" do
+      wait_for { find(".select2-results__options li", text: value).visible? rescue false }
+      find("li", text: value).hover
+      find("li", text: value).click
     end
+    sleep 0.15
+    select2_chosen_selector(attrs[:from]).has_text? value
   end
 
   def wait_for
@@ -267,11 +281,11 @@ class ActionDispatch::IntegrationTest
 
   def refute_available_organization_dropdown(organization)
     within('#location-dropdown') do
-      find('.pf-c-context-selector__toggle').click
-      within('.pf-c-context-selector__menu>div>ul', visible: :all) do
+      find('.pf-v5-c-context-selector__toggle').click
+      within('.pf-v5-c-context-selector__menu>div>ul', visible: :all) do
         assert page.has_no_link?(organization)
       end
-      find('.pf-c-context-selector__toggle').click
+      find('.pf-v5-c-context-selector__toggle').click
     end
   end
 
@@ -298,7 +312,7 @@ class ActionDispatch::IntegrationTest
 
   def select_organization_dropdown(organization)
     within('#organization-dropdown') do
-      find('.pf-c-context-selector__toggle').click
+      find('.pf-v5-c-context-selector__toggle').click
       find("button.organization_menuitem", text: organization).click
     end
   end
@@ -306,13 +320,13 @@ class ActionDispatch::IntegrationTest
   def select_organization_menu(organization)
     within('.organization-menu') do
       first('button').click
-      find("li.pf-c-nav__item", text: organization).click
+      find("li.pf-v5-c-nav__item", text: organization).click
     end
   end
 
   def select_location_dropdown(location)
     within('#location-dropdown') do
-      find('.pf-c-context-selector__toggle').click
+      find('.pf-v5-c-context-selector__toggle').click
       find("button.location_menuitem", text: location).click
     end
   end
