@@ -66,6 +66,7 @@ export function activateDatatables() {
   $('[data-table=inline]')
     .not('.dataTable')
     .DataTable({
+      pagingType: 'simple_numbers',
       language,
       dom: "<'row'<'col-md-6'f>r>t<'row'<'col-md-6'i><'col-md-6'p>>",
     });
@@ -76,6 +77,7 @@ export function activateDatatables() {
       const url = el.getAttribute('data-source');
 
       $(el).DataTable({
+        pagingType: 'simple_numbers',
         language,
         processing: true,
         serverSide: true,
@@ -123,16 +125,19 @@ export function highlightTabErrors() {
   errorFields.parents('.tab-pane').each(function fn() {
     $(`a[href="#${this.id}"]`).addClass('tab-error');
   });
-  $('.tab-error')
-    .first()
-    .click();
-  $('.nav-pills .tab-error')
-    .first()
-    .click();
+  const firstTabError = document.querySelector('.tab-error');
+  if (firstTabError) {
+    $(firstTabError).tab('show');
+  }
+  const firstNestedTabError = document.querySelector('.nav-pills .tab-error');
+  if (firstNestedTabError) {
+    $(firstNestedTabError).tab('show');
+  }
+
   errorFields
     .first()
     .find('.form-control')
-    .focus();
+    .trigger('focus');
 }
 
 export const loadPluginModule = async (url, scope, module, plugin = true) => {
