@@ -1,15 +1,13 @@
 import PropTypes from 'prop-types';
 import React, { useState, createContext } from 'react';
 import { useSelector, shallowEqual, useDispatch } from 'react-redux';
+import { Button, Split, SplitItem } from '@patternfly/react-core';
 import {
-  Button,
   DropdownItem,
   Dropdown,
   DropdownSeparator,
   KebabToggle,
-  Split,
-  SplitItem,
-} from '@patternfly/react-core';
+} from '@patternfly/react-core/deprecated';
 import {
   DatabaseIcon,
   TrashIcon,
@@ -23,7 +21,10 @@ import { translate as __ } from '../../../common/I18n';
 import { selectKebabItems } from './Selectors';
 import { foremanUrl } from '../../../common/helpers';
 import { cancelBuild, deleteHost, isHostTurnOn } from './actions';
-import { useForemanSettings } from '../../../Root/Context/ForemanContext';
+import {
+  useForemanSettings,
+  useForemanHostsPageUrl,
+} from '../../../Root/Context/ForemanContext';
 import BuildModal from './BuildModal';
 import Slot from '../../common/Slot';
 
@@ -51,12 +52,15 @@ const ActionsBar = ({
   const [isBuildModalOpen, setBuildModal] = useState(false);
   const onKebabToggle = isOpen => setKebab(isOpen);
   const { destroyVmOnHostDelete } = useForemanSettings();
+  const hostsIndexUrl = useForemanHostsPageUrl();
   const registeredItems = useSelector(selectKebabItems, shallowEqual);
   const isHostActive = useSelector(isHostTurnOn);
 
   const dispatch = useDispatch();
   const deleteHostHandler = () =>
-    dispatch(deleteHost(hostName, computeId, destroyVmOnHostDelete));
+    dispatch(
+      deleteHost(hostName, computeId, destroyVmOnHostDelete, hostsIndexUrl)
+    );
 
   const isConsoleDisabled = !(computeId && isHostActive);
   const determineTooltip = () => {
@@ -159,7 +163,10 @@ const ActionsBar = ({
               ouiaId="kebab-dropdown"
               alignments={{ default: 'right' }}
               toggle={
-                <KebabToggle id="hostdetails-kebab" onToggle={onKebabToggle} />
+                <KebabToggle
+                  id="hostdetails-kebab"
+                  onToggle={(_event, isOpen) => onKebabToggle(isOpen)}
+                />
               }
               isOpen={kebabIsOpen}
               isPlain
