@@ -5,10 +5,7 @@ import { Tr, Td, ActionsColumn } from '@patternfly/react-table';
 import {
   ToolbarItem,
   Divider,
-  Dropdown,
-  DropdownItem,
   MenuItem,
-  KebabToggle,
   Flex,
   FlexItem,
   Button,
@@ -17,6 +14,11 @@ import {
   TextContent,
   Text,
 } from '@patternfly/react-core';
+import {
+  Dropdown,
+  DropdownItem,
+  KebabToggle,
+} from '@patternfly/react-core/deprecated';
 import { UndoIcon } from '@patternfly/react-icons';
 import { useForemanModal } from '../ForemanModal/ForemanModalHooks';
 import { addModal } from '../ForemanModal/ForemanModalActions';
@@ -37,7 +39,10 @@ import {
   getPageStats,
 } from '../PF4/TableIndexPage/Table/helpers';
 import { deleteHost } from '../HostDetails/ActionsBar/actions';
-import { useForemanSettings } from '../../Root/Context/ForemanContext';
+import {
+  useForemanSettings,
+  useForemanHostsPageUrl,
+} from '../../Root/Context/ForemanContext';
 import { bulkDeleteHosts } from './BulkActions/bulkDelete';
 import BulkBuildHostModal from './BulkActions/buildHosts';
 import BulkReassignHostgroupModal from './BulkActions/reassignHostGroup';
@@ -103,15 +108,20 @@ const HostsIndex = () => {
     setAPIOptions: response.setAPIOptions,
   });
 
+  /* eslint-disable consistent-return */
   useEffect(() => {
     const handleLoadJS = () => {
       setAllColumns(getColumnData({ tableName: 'hosts' }));
       setAllJsLoaded(true);
     };
-    document.addEventListener('loadJS', handleLoadJS);
-    return () => {
-      document.removeEventListener('loadJS', handleLoadJS);
-    };
+    if (window.allJsLoaded) {
+      handleLoadJS();
+    } else {
+      document.addEventListener('loadJS', handleLoadJS);
+      return () => {
+        document.removeEventListener('loadJS', handleLoadJS);
+      };
+    }
   }, [setAllColumns]);
   const {
     hasPreference,
@@ -177,8 +187,11 @@ const HostsIndex = () => {
 
   const dispatch = useDispatch();
   const { destroyVmOnHostDelete } = useForemanSettings();
+  const hostsIndexUrl = useForemanHostsPageUrl();
   const deleteHostHandler = ({ hostName, computeId }) =>
-    dispatch(deleteHost(hostName, computeId, destroyVmOnHostDelete));
+    dispatch(
+      deleteHost(hostName, computeId, destroyVmOnHostDelete, hostsIndexUrl)
+    );
   const handleBulkDelete = () => {
     const bulkParams = fetchBulkParams();
     dispatch(
@@ -302,7 +315,7 @@ const HostsIndex = () => {
         <KebabToggle
           aria-label="legacy-ui-kebab-toggle"
           id="legacy-ui-kebab-toggle"
-          onToggle={setLegacyUIKebabOpen}
+          onToggle={(_event, val) => setLegacyUIKebabOpen(val)}
         />
       }
       isOpen={legacyUIKebabOpen}
@@ -408,7 +421,7 @@ const HostsIndex = () => {
         {results?.map((result, rowIndex) => {
           const rowActions = getActions(result);
           return (
-            <Tr key={rowIndex} ouiaId={`table-row-${rowIndex}`} isHoverable>
+            <Tr key={rowIndex} ouiaId={`table-row-${rowIndex}`} isClickable>
               {<RowSelectTd rowData={result} {...{ selectOne, isSelected }} />}
               {columnNamesKeys.map(k => (
                 <Td key={k} dataLabel={keysToColumnNames[k]}>
