@@ -13,18 +13,18 @@ describe('ToastsList', () => {
         <ToastsList />
       </Provider>);
 
-    let alerts = component.find('.pf-c-alert.foreman-toast');
+    let alerts = component.find('.pf-v5-c-alert.foreman-toast');
     expect(alerts.length).toBe(0);
 
     store.dispatch(addToast(toast));
     component.update();
-    alerts = component.find('.pf-c-alert.foreman-toast');
+    alerts = component.find('.pf-v5-c-alert.foreman-toast');
     expect(alerts.length).toBe(1);
-    expect(component.find('.pf-c-alert__title').at(0).text()).toBe('Success alert:message');
+    expect(component.find('.pf-v5-c-alert__title').at(0).text()).toBe('Success alert:message');
 
     store.dispatch(deleteToast(toast.key));
     component.update();
-    alerts = component.find('.pf-c-alert.foreman-toast');
+    alerts = component.find('.pf-v5-c-alert.foreman-toast');
     expect(alerts.length).toBe(0);
   });
 });
